@@ -48,17 +48,25 @@ test_that("get_nhdplus_bybox", {
 test_that("downloaders run", {
   skip_on_cran()
   dir <- tempdir()
-  mess <- capture_messages(out <- download_nhdplusv2(outdir = dir, url = "https://usgs-r.github.io/nhdplusTools/data/NHDPlus_test.gdb.7z"))
+  mess <- capture_messages(
+    out <- download_nhdplusv2(outdir = dir,
+                              url = "https://usgs-r.github.io/nhdplusTools/data/NHDPlus_test.gdb.7z",
+                              progress = FALSE))
   unlink(dir, recursive = T)
   expect_true(grepl("NHDPlus_test.gdb", out))
 
   dir <- tempdir()
-  mess <- capture_messages(out <- download_rf1(outdir = dir, url = "https://usgs-r.github.io/nhdplusTools/data/rf1_test.e00.gz"))
+  mess <- capture_messages(
+    out <- download_rf1(outdir = dir,
+                        url = "https://usgs-r.github.io/nhdplusTools/data/rf1_test.e00.gz",
+                        progress = FALSE))
   unlink(dir, recursive = T)
   expect_true(grepl("rf1_test.e00", out))
 
   dir <- tempdir()
-  mess <- capture_messages(out <- download_wbd(outdir = dir, url = "https://usgs-r.github.io/nhdplusTools/data/WBD_test.gdb.zip"))
+  temp <- capture.output(mess <- capture_messages(out <- download_wbd(outdir = dir,
+                                               url = "https://usgs-r.github.io/nhdplusTools/data/WBD_test.gdb.zip",
+                                               progress = TRUE)))
   unlink(dir, recursive = T)
   expect_true(grepl("WBD_test.gdb", out))
 })
